@@ -39,6 +39,7 @@ CRO = Coin("CRO")
 CRV = Coin("CRV")
 CSPR = Coin("CSPR")
 CTSI = Coin("CTSI")
+CVX = Coin("CVX")
 DAI = Coin("DAI")
 DAR = Coin("DAR")
 DERC = Coin("DERC")
@@ -113,6 +114,7 @@ ONE = Coin("ONE")
 ONEINCH = Coin("1INCH")
 ONT = Coin("ONT")
 OXT = Coin("OXT")
+PAX = Coin("PAX")
 PAXG = Coin("PAXG")
 PENDLE = Coin("PENDLE")
 PERP = Coin("PERP")
