@@ -26,6 +26,7 @@ AUDIO_USDT = Pair("AUDIO_USDT", price_precision=4, quantity_precision=2)
 AVAX_BTC = Pair("AVAX_BTC", price_precision=7, quantity_precision=3)
 AVAX_USDC = Pair("AVAX_USDC", price_precision=3, quantity_precision=3)
 AVAX_USDT = Pair("AVAX_USDT", price_precision=3, quantity_precision=3)
+AXS_BTC = Pair("AXS_BTC", price_precision=7, quantity_precision=3)
 AXS_USDT = Pair("AXS_USDT", price_precision=4, quantity_precision=2)
 BADGER_USDT = Pair("BADGER_USDT", price_precision=3, quantity_precision=3)
 BAL_USDT = Pair("BAL_USDT", price_precision=3, quantity_precision=3)
@@ -56,9 +57,11 @@ CQT_USDT = Pair("CQT_USDT", price_precision=4, quantity_precision=2)
 CRO_BTC = Pair("CRO_BTC", price_precision=9, quantity_precision=2)
 CRO_USDC = Pair("CRO_USDC", price_precision=5, quantity_precision=3)
 CRO_USDT = Pair("CRO_USDT", price_precision=5, quantity_precision=3)
+CRV_BTC = Pair("CRV_BTC", price_precision=8, quantity_precision=2)
 CRV_CRO = Pair("CRV_CRO", price_precision=3, quantity_precision=2)
 CRV_USDT = Pair("CRV_USDT", price_precision=4, quantity_precision=4)
 CTSI_USDT = Pair("CTSI_USDT", price_precision=5, quantity_precision=1)
+CVX_USDT = Pair("CVX_USDT", price_precision=3, quantity_precision=3)
 DAI_CRO = Pair("DAI_CRO", price_precision=3, quantity_precision=3)
 DAI_USDC = Pair("DAI_USDC", price_precision=4, quantity_precision=2)
 DAI_USDT = Pair("DAI_USDT", price_precision=4, quantity_precision=3)
@@ -148,6 +151,7 @@ LRC_USDT = Pair("LRC_USDT", price_precision=5, quantity_precision=2)
 LTC_BTC = Pair("LTC_BTC", price_precision=6, quantity_precision=4)
 LTC_USDC = Pair("LTC_USDC", price_precision=2, quantity_precision=4)
 LTC_USDT = Pair("LTC_USDT", price_precision=2, quantity_precision=5)
+LUNA_BTC = Pair("LUNA_BTC", price_precision=7, quantity_precision=3)
 LUNA_USDC = Pair("LUNA_USDC", price_precision=3, quantity_precision=3)
 LUNA_USDT = Pair("LUNA_USDT", price_precision=4, quantity_precision=2)
 MANA_BTC = Pair("MANA_BTC", price_precision=9, quantity_precision=1)
@@ -223,8 +227,10 @@ SOL_USDT = Pair("SOL_USDT", price_precision=3, quantity_precision=3)
 SPELL_USDC = Pair("SPELL_USDC", price_precision=6, quantity_precision=0)
 SRM_USDC = Pair("SRM_USDC", price_precision=4, quantity_precision=2)
 STORJ_USDT = Pair("STORJ_USDT", price_precision=4, quantity_precision=2)
+STRAX_USDT = Pair("STRAX_USDT", price_precision=4, quantity_precision=2)
 STX_USDT = Pair("STX_USDT", price_precision=4, quantity_precision=2)
 SUPER_USDT = Pair("SUPER_USDT", price_precision=4, quantity_precision=2)
+SUSHI_BTC = Pair("SUSHI_BTC", price_precision=8, quantity_precision=2)
 SUSHI_USDT = Pair("SUSHI_USDT", price_precision=3, quantity_precision=3)
 TFUEL_USDT = Pair("TFUEL_USDT", price_precision=5, quantity_precision=1)
 THETA_USDT = Pair("THETA_USDT", price_precision=4, quantity_precision=2)
